pub fn name_cell(book: &NameBook, did: &str) -> Cell<'static>Expand description
A name cell for did.
Unverified agent names are yellow — see vta_sdk::display_name for why
they must stay visually distinct from a name the operator can rely on.
pub fn name_cell(book: &NameBook, did: &str) -> Cell<'static>A name cell for did.
Unverified agent names are yellow — see vta_sdk::display_name for why
they must stay visually distinct from a name the operator can rely on.